summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--.Attic/README.old_stage226
-rw-r--r--TODOS9
-rwxr-xr-xbuild_stage2.sh5
-rw-r--r--i486-stage2/git/DESCR23
-rw-r--r--i486-stage2/libtool/DESCR3
-rwxr-xr-xinstall_host.sh3
6 files changed, 34 insertions, 35 deletions
diff --git a/.Attic/README.old_stage2 b/.Attic/README.old_stage2
index 6a04756..d5899f5 100644
--- a/.Attic/README.old_stage2
+++ b/.Attic/README.old_stage2
@@ -164,28 +164,10 @@ arch-chroot /home/cross/i486-root/
# package specific things
-# perl
-######
-perl: warning: Please check that your locale settings:
- LANGUAGE = (unset),
- LC_ALL = (unset),
- LANG = "en_US.UTF-8"
- are supported and installed on your system.
-
-# openssl
-sed -i 's@i686@i486@g' openssl/PKGBUILD
-sed -i 's@no-ssl3-method@no-sse2 no-ssl3-method@g' openssl/PKGBUILD
-
# xz
# with gcc 7.2 we get new errors
sed -i 's@--enable-werror@--disable-werror@g' xz/PKGBUILD
-# help2man
-# needs perl-locale-gettext, which needs gettext, which needs glib2
-# which needs meson (so a big nogo currently!)
-# obviously it builds also without gettext..
-sed -i 's@^depends\(.*\)@#depends\1@g' help2man/PKGBUILD
-
# bc
# requires texinfo, is this part of base-devel?
# bootstrap --force
@@ -735,14 +717,14 @@ https://git.busybox.net/buildroot/diff/package/glibc/0005-fix-binutils-2-29-buil
{standard input}: Error: `locs@GLIBC_2.0' can't be versioned to common symbol 'locs'
make[2]: *** [../o-iterator.mk:9: /build/glibc/src/glibc-build/misc/regexp.os] Error 1
-PACKAGES="iana-etc filesystem linux-api-headers tzdata ncurses readline bash \
-gdbm perl openssl bzip2 xz m4 help2man flex bc elfutils \
+PACKAGES=" \
+bzip2 xz flex bc elfutils \
libtool libxml2 libgpg-error libgcrypt libxslt \
docbook-xml docbook-xsl xmlto libcap libtirpc pambase pam inetutils bison iproute2 kmod \
sysfsutils libidn iputils \
expat acl attr lz4 tar libarchive curl pacman \
joe coreutils util-linux pcre grep findutils file diffutils ed patch \
-autoconf automake libedit openssh pcre2 git libunwind strace wget \
+autoconf automake libedit openssh libunwind strace wget \
gmp mpfr gawk libmpc zlib tcl expect dejagnu binutils gcc libtool glibc"
for p in $PACKAGES; do
asp export $p
@@ -755,8 +737,6 @@ for p in $PACKAGES
# for some packages we cannot execute tests (because the dependencies to install in
# the toolchain environment would be too much)
- # perl: --nocheck
- # openssl: --nocheck
# libelf: --nocheck
# libtool: --nocheck
# libxml2: --nocheck
diff --git a/TODOS b/TODOS
index 8c69d20..c770bd4 100644
--- a/TODOS
+++ b/TODOS
@@ -64,10 +64,5 @@ stage2 issues:
error: could not register 'temp' database (wrong or NULL argument passed)
error: no usable package repositories configured.
=> we cannot install via the [temp] repo
-- copying every single file is not a really smart idea:
- do not copy expanded sources in 'src' from host to target
- (our expectiation is makepkg -o -e would do the trick, but it doesn't)
-- git sources are a problem. we must package 'src' on the host and scp
- it to a named package-git.tar.gz, then patch PKGBUILD to make it use
- this local file instead of trying to checkout from git
-
+ => on the long term, debug pacman and libalpm and see what could be the root cause
+- our expectiation is makepkg -o -e would do the trick, but it doesn't
diff --git a/i486-stage2/git/DESCR b/i486-stage2/git/DESCR
new file mode 100644
index 0000000..e95d538
--- /dev/null
+++ b/i486-stage2/git/DESCR
@@ -0,0 +1,23 @@
+# no python2
+sed -i "/makedepends=/s/'python2'//" PKGBUILD
+
+# no Gnome integration
+sed -i "/makedepends=/s/'libgnome-keyring'//" PKGBUILD
+sed -i "s@\(make -C contrib/credential/gnome-keyring\)@#\1@" PKGBUILD
+
+# no Emacs
+sed -i "/makedepends=/s/'emacs'//" PKGBUILD
+sed -i "s@\(make -C contrib/emacs prefix=/usr\)@#\1@" PKGBUILD
+
+# no documentation
+sed -i "/makedepends=/s/'xmlto'//" PKGBUILD
+sed -i "/makedepends=/s/'asciidoc'//" PKGBUILD
+sed -i "s/all doc/all/g" PKGBUILD
+sed -i "s/install install-doc/install/g" PKGBUILD
+
+# git-credential-libsecret.c:29:10: fatal error: glib.h: No such file or directory
+# include <glib.h>
+sed -i "s@\(make -C contrib/credential/libsecret\)@#\1@" PKGBUILD
+sed -i "/# gnome credentials helper/,/make -C contrib\/credential\/libsecret clean/s/\(.*\)/#\1/g" PKGBUILD
+
+# not configured with configure? weird..
diff --git a/i486-stage2/libtool/DESCR b/i486-stage2/libtool/DESCR
deleted file mode 100644
index 569e8a9..0000000
--- a/i486-stage2/libtool/DESCR
+++ /dev/null
@@ -1,3 +0,0 @@
-# we checkout on the host and scp to the target and don't use git on the target
-# (because we don't have it yet)
-sed -i "/makedepends=/s/git//" PKGBUILD
diff --git a/install_host.sh b/install_host.sh
index aaade23..cfe9399 100755
--- a/install_host.sh
+++ b/install_host.sh
@@ -42,6 +42,9 @@ case $BUILD_CPU in
;;
esac
+# for building git (stage 2)
+pacman --noconfirm --needed -S libgnome-keyring xmlto
+
# some packages come from the AUR
if test "$(grep -c '\[archlinuxfr\]' /etc/pacman.conf)" = 0; then
cat >> /etc/pacman.conf <<EOF
diff --git a/build_stage2.sh b/build_stage2.sh
index d9b48c2..b8c849e 100755
--- a/build_stage2.sh
+++ b/build_stage2.sh
@@ -14,10 +14,11 @@ iana-etc filesystem linux-api-headers tzdata
ncurses readline joe
attr acl m4 gmp gdbm db perl openssl
libunistring gettext perl-locale-gettext help2man
-autoconf automake libtool
+autoconf automake perl-error pcre2 git
"
#~ zlib pambase cracklib libtirpc pam libcap coreutils
#~ util-linux e2fsprogs
#~ expat bzip2 lz4 xz pcre less gzip tar libarchive curl
#~ pacman-mirrorlist archlinux-keyring archlinux32-keyring pacman
@@ -14,10 +14,11 @@ iana-etc filesystem linux-api-headers tzdata
"
-#~ zlib pambase cracklib libtirpc pam libcap coreutils
+#~ git
+#~ libtool zlib pambase cracklib libtirpc pam libcap coreutils
#~ util-linux e2fsprogs
#~ expat bzip2 lz4 xz pcre less gzip tar libarchive curl